@@ -1,8 +1,3 @@
-# -*- coding: utf-8 -*-
-# Copyright (c) Zbigniew Siciarz 2012-2014.
-
-from __future__ import unicode_literals
-
 """
 Administration for photos and galleries.
 """
@@ -11,49 +6,58 @@ from django.contrib import admin
 from django.db.models import Count
 from django.utils.translation import ugettext_lazy as _
 
-import reversion
-from sorl.thumbnail.admin import AdminImageMixin
-
 from .forms import PhotoForm
 from .models import Gallery, Photo
 
 
-class PhotoInline(AdminImageMixin, admin.TabularInline):
+class PhotoInline(admin.TabularInline):
     """
     Administration for photos.
     """
+
     model = Photo
     form = PhotoForm
-    ordering = ['created']
+    ordering = ["created"]
+
+    def get_extra(self, request, obj=None, **kwargs):
+        return 0 if obj else 3
 
 
-class GalleryAdmin(reversion.VersionAdmin):
+class GalleryAdmin(admin.ModelAdmin):
     """
     Administration for galleries.
     """
+
     list_display = (
-        'author', 'title', 'status', 'description', 'shot_date', 'modified',
-        'photo_count',
+        "author",
+        "title",
+        "status",
+        # Having "description" here raises SystemCheckError (admin.E108).
+        # We need to remove description from list_display for Django 2.1-2.2
+        # See https://code.djangoproject.com/ticket/30543
+        # "description",
+        "shot_date",
+        "modified",
+        "photo_count",
     )
-    list_display_links = ('title',)
-    list_editable = ('status',)
-    list_filter = ('status',)
-    date_hierarchy = 'shot_date'
-    prepopulated_fields = {'slug': ('title',)}
+    list_display_links = ("title",)
+    list_editable = ("status",)
+    list_filter = ("status",)
+    date_hierarchy = "shot_date"
+    prepopulated_fields = {"slug": ("title",)}
     inlines = [PhotoInline]
 
     def photo_count(self, obj):
         return obj.photo_count
+
     photo_count.short_description = _("Photo count")
 
-    def queryset(self, request):
+    def get_queryset(self, request):
         """
         Add number of photos to each gallery.
-
-        TODO rename to get_queryset for Django 1.6.
         """
-        qs = super(GalleryAdmin, self).queryset(request)
-        return qs.annotate(photo_count=Count('photos'))
+        qs = super(GalleryAdmin, self).get_queryset(request)
+        return qs.annotate(photo_count=Count("photos"))
 
     def save_model(self, request, obj, form, change):
         """
